# Generated by roxygen2: do not edit by hand

S3method(tmapMapboxAuxPlot,default)
S3method(tmapMapboxAuxPlot,tm_aux_basemap)
S3method(tmapMapboxAuxPlot,tm_aux_rain)
S3method(tmapMapboxAuxPlot,tm_aux_snow)
S3method(tmapMapboxAuxPlot,tm_aux_tiles)
S3method(tmapMapboxAuxPrepare,default)
S3method(tmapMapboxAuxPrepare,tm_aux_basemap)
S3method(tmapMapboxAuxPrepare,tm_aux_rain)
S3method(tmapMapboxAuxPrepare,tm_aux_snow)
S3method(tmapMapboxAuxPrepare,tm_aux_tiles)
S3method(tmapMapboxCompHeight,tm_geocoder)
S3method(tmapMapboxCompHeight,tm_legend_landscape)
S3method(tmapMapboxCompHeight,tm_legend_portrait)
S3method(tmapMapboxCompHeight,tm_minimap)
S3method(tmapMapboxCompHeight,tm_scalebar)
S3method(tmapMapboxCompHeight,tm_snow)
S3method(tmapMapboxCompHeight,tm_title)
S3method(tmapMapboxCompPlot,tm_geocoder)
S3method(tmapMapboxCompPlot,tm_legend_landscape)
S3method(tmapMapboxCompPlot,tm_legend_portrait)
S3method(tmapMapboxCompPlot,tm_minimap)
S3method(tmapMapboxCompPlot,tm_scalebar)
S3method(tmapMapboxCompPlot,tm_snow)
S3method(tmapMapboxCompPlot,tm_title)
S3method(tmapMapboxCompPrepare,default)
S3method(tmapMapboxCompPrepare,tm_chart_none)
S3method(tmapMapboxCompPrepare,tm_geocoder)
S3method(tmapMapboxCompPrepare,tm_legend_landscape)
S3method(tmapMapboxCompPrepare,tm_legend_portrait)
S3method(tmapMapboxCompPrepare,tm_minimap)
S3method(tmapMapboxCompPrepare,tm_scalebar)
S3method(tmapMapboxCompPrepare,tm_snow)
S3method(tmapMapboxCompPrepare,tm_title)
S3method(tmapMapboxCompWidth,tm_geocoder)
S3method(tmapMapboxCompWidth,tm_legend_landscape)
S3method(tmapMapboxCompWidth,tm_legend_portrait)
S3method(tmapMapboxCompWidth,tm_minimap)
S3method(tmapMapboxCompWidth,tm_scalebar)
S3method(tmapMapboxCompWidth,tm_snow)
S3method(tmapMapboxCompWidth,tm_title)
S3method(tmapMapboxDataPlot,default)
S3method(tmapMapboxDataPlot,tm_data_borders)
S3method(tmapMapboxDataPlot,tm_data_bubbles)
S3method(tmapMapboxDataPlot,tm_data_dots)
S3method(tmapMapboxDataPlot,tm_data_fill)
S3method(tmapMapboxDataPlot,tm_data_lines)
S3method(tmapMapboxDataPlot,tm_data_polygons)
S3method(tmapMapboxDataPlot,tm_data_polygons_3d)
S3method(tmapMapboxDataPlot,tm_data_raster)
S3method(tmapMapboxDataPlot,tm_data_symbols)
S3method(tmapMaplibreAuxPlot,default)
S3method(tmapMaplibreAuxPlot,tm_aux_basemap)
S3method(tmapMaplibreAuxPlot,tm_aux_tiles)
S3method(tmapMaplibreAuxPrepare,default)
S3method(tmapMaplibreAuxPrepare,tm_aux_basemap)
S3method(tmapMaplibreAuxPrepare,tm_aux_tiles)
S3method(tmapMaplibreCompHeight,tm_credits)
S3method(tmapMaplibreCompHeight,tm_geocoder)
S3method(tmapMaplibreCompHeight,tm_legend_landscape)
S3method(tmapMaplibreCompHeight,tm_legend_portrait)
S3method(tmapMaplibreCompHeight,tm_minimap)
S3method(tmapMaplibreCompHeight,tm_mouse_coordinates)
S3method(tmapMaplibreCompHeight,tm_scalebar)
S3method(tmapMaplibreCompHeight,tm_title)
S3method(tmapMaplibreCompPlot,tm_credits)
S3method(tmapMaplibreCompPlot,tm_geocoder)
S3method(tmapMaplibreCompPlot,tm_legend_landscape)
S3method(tmapMaplibreCompPlot,tm_legend_portrait)
S3method(tmapMaplibreCompPlot,tm_minimap)
S3method(tmapMaplibreCompPlot,tm_mouse_coordinates)
S3method(tmapMaplibreCompPlot,tm_scalebar)
S3method(tmapMaplibreCompPlot,tm_title)
S3method(tmapMaplibreCompPrepare,default)
S3method(tmapMaplibreCompPrepare,tm_chart_none)
S3method(tmapMaplibreCompPrepare,tm_credits)
S3method(tmapMaplibreCompPrepare,tm_geocoder)
S3method(tmapMaplibreCompPrepare,tm_legend_landscape)
S3method(tmapMaplibreCompPrepare,tm_legend_portrait)
S3method(tmapMaplibreCompPrepare,tm_minimap)
S3method(tmapMaplibreCompPrepare,tm_mouse_coordinates)
S3method(tmapMaplibreCompPrepare,tm_scalebar)
S3method(tmapMaplibreCompPrepare,tm_title)
S3method(tmapMaplibreCompWidth,tm_credits)
S3method(tmapMaplibreCompWidth,tm_geocoder)
S3method(tmapMaplibreCompWidth,tm_legend_landscape)
S3method(tmapMaplibreCompWidth,tm_legend_portrait)
S3method(tmapMaplibreCompWidth,tm_minimap)
S3method(tmapMaplibreCompWidth,tm_mouse_coordinates)
S3method(tmapMaplibreCompWidth,tm_scalebar)
S3method(tmapMaplibreCompWidth,tm_title)
S3method(tmapMaplibreDataPlot,default)
S3method(tmapMaplibreDataPlot,tm_data_borders)
S3method(tmapMaplibreDataPlot,tm_data_bubbles)
S3method(tmapMaplibreDataPlot,tm_data_dots)
S3method(tmapMaplibreDataPlot,tm_data_fill)
S3method(tmapMaplibreDataPlot,tm_data_lines)
S3method(tmapMaplibreDataPlot,tm_data_polygons)
S3method(tmapMaplibreDataPlot,tm_data_polygons_3d)
S3method(tmapMaplibreDataPlot,tm_data_raster)
S3method(tmapMaplibreDataPlot,tm_data_symbols)
export(opt_tm_polygons_3d)
export(renderTmapMapbox)
export(renderTmapMaplibre)
export(tm_geocoder)
export(tm_mapbox)
export(tm_maplibre)
export(tm_polygons_3d)
export(tm_rain)
export(tm_snow)
export(tmapMapboxArrange)
export(tmapMapboxAux)
export(tmapMapboxAuxPlot)
export(tmapMapboxAuxPrepare)
export(tmapMapboxComp)
export(tmapMapboxCompHeight)
export(tmapMapboxCompPlot)
export(tmapMapboxCompPrepare)
export(tmapMapboxCompWidth)
export(tmapMapboxDataPlot)
export(tmapMapboxGridXLab)
export(tmapMapboxGridYLab)
export(tmapMapboxInit)
export(tmapMapboxOverlay)
export(tmapMapboxProviders)
export(tmapMapboxRun)
export(tmapMapboxShape)
export(tmapMapboxWrap)
export(tmapMapboxXtab)
export(tmapMaplibreArrange)
export(tmapMaplibreAux)
export(tmapMaplibreAuxPlot)
export(tmapMaplibreAuxPrepare)
export(tmapMaplibreComp)
export(tmapMaplibreCompHeight)
export(tmapMaplibreCompPlot)
export(tmapMaplibreCompPrepare)
export(tmapMaplibreCompWidth)
export(tmapMaplibreDataPlot)
export(tmapMaplibreGridXLab)
export(tmapMaplibreGridYLab)
export(tmapMaplibreInit)
export(tmapMaplibreOverlay)
export(tmapMaplibreProviders)
export(tmapMaplibreRun)
export(tmapMaplibreShape)
export(tmapMaplibreWrap)
export(tmapMaplibreXtab)
export(tmapOutputMapbox)
export(tmapOutputMaplibre)
export(tmapProxyMapbox)
export(tmapProxyMaplibre)
export(tmapValuesCVV_height)
export(tmapValuesCheck_height)
export(tmapValuesColorize_height)
export(tmapValuesIsDiv_height)
export(tmapValuesRange_height)
export(tmapValuesScale_height)
export(tmapValuesSubmit_height)
export(tmapValuesVV_height)
export(tmap_mapbox)
export(tmap_maplibre)
import(cli)
import(data.table)
import(sf)
import(stars)
importFrom(colorspace,deutan)
importFrom(colorspace,protan)
importFrom(colorspace,tritan)
importFrom(grDevices,col2rgb)
importFrom(grDevices,rgb)
importFrom(htmltools,tags)
importFrom(htmlwidgets,prependContent)
importFrom(stats,na.omit)
importFrom(terra,crop)
importFrom(terra,ext)
importFrom(terra,is.lonlat)
importFrom(terra,project)
importFrom(terra,rast)
importFrom(tmaptools,bb_poly)
importFrom(units,drop_units)
importFrom(units,set_units)
importFrom(utils,head)
importFrom(utils,tail)
