#' @param tms tmap objects
#' @param nx number of facets
#' @param ncol, nrow number of rows and columns
#' @param opts options
#' @param knit knit
#' @param show show
#' @param args args
#' @param options options
#' @export
#' @keywords internal
#' @name tmapMapboxArrange
#' @rdname tmapMapbox
tmapMapboxArrange = function(tms, nx, ncol, nrow, opts, knit, show, args, options) {
	stop("arrange not implemented yet for mapbox")
}

#' @export
#' @keywords internal
#' @rdname tmapMapbox
tmapMaplibreArrange = function(tms, nx, ncol, nrow, opts, knit, show, args, options) {
	stop("arrange not implemented yet for maplibre")
}
