
#' @param label label
#' @export
#' @keywords internal
#' @rdname tmapMapbox
tmapMapboxWrap = function(label, facet_row, facet_col, facet_page, o) {
	NULL
}


#' @export
#' @keywords internal
#' @rdname tmapMapbox
tmapMapboxXtab = function(label, facet_row, facet_col, facet_page, o) {
	NULL
}


#' @param label label
#' @export
#' @keywords internal
#' @rdname tmapMapbox
tmapMaplibreWrap = function(label, facet_row, facet_col, facet_page, o) {
	NULL
}


#' @export
#' @keywords internal
#' @rdname tmapMapbox
tmapMaplibreXtab = function(label, facet_row, facet_col, facet_page, o) {
	NULL
}
