#' @export
#' @keywords internal
#' @rdname tmapMapbox
tmapValuesCheck_height = tmap::tmapValuesCheck_size
#' @export
#' @keywords internal
#' @rdname tmapMapbox
tmapValuesIsDiv_height = tmap::tmapValuesIsDiv_size
#' @export
#' @keywords internal
#' @rdname tmapMapbox
tmapValuesRange_height = tmap::tmapValuesRange_size
#' @export
#' @keywords internal
#' @rdname tmapMapbox
tmapValuesVV_height = tmap::tmapValuesVV_size
#' @export
#' @keywords internal
#' @rdname tmapMapbox
tmapValuesSubmit_height = tmap::tmapValuesSubmit_size
#' @export
#' @keywords internal
#' @rdname tmapMapbox
tmapValuesScale_height = tmap::tmapValuesScale_size
#' @export
#' @keywords internal
#' @rdname tmapMapbox
tmapValuesColorize_height = tmap::tmapValuesColorize_size
#' @export
#' @keywords internal
#' @rdname tmapMapbox
tmapValuesCVV_height = tmap::tmapValuesCVV_size
